@@ -1,9 +1,9 @@
 /* File getfits.c
- * April 13, 2010
+ * September 17, 2013
  * By Jessica Mink, Harvard-Smithsonian Center for Astrophysics
  * Send bug reports to jmink@cfa.harvard.edu
 
-   Copyright (C) 2002-2010
+   Copyright (C) 2002-2013
    Smithsonian Astrophysical Observatory, Cambridge, MA USA
 
    This program is free software; you can redistribute it and/or
@@ -28,8 +28,7 @@
 #include <errno.h>
 #include <unistd.h>
 #include <math.h>
-#include "libwcs/fitsfile.h"
-#include "libwcs/wcs.h"
+#include "libwcs/fitswcs.h"
 #include "libwcs/wcscat.h"
 
 #define MAXRANGE 20
@@ -44,7 +43,7 @@ static void nextname();	/* Find next available name (namea, nameb, ...) */
 static int ExtractFITS();
 
 static int verbose = 0;		/* verbose/debugging flag */
-static char *RevMsg = "GETFITS WCSTools 3.8.7, 31 October 2012, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "GETFITS WCSTools 3.9.0, 29 August 2014, Jessica Mink (jmink@cfa.harvard.edu)";
 static int version = 0;		/* If 1, print only program name and version */
 static char outname[128];	/* Name for output image */
 static char outdir[256];	/* Output directory pathname */
@@ -230,7 +229,7 @@ char **av;
 		}
     	    }
 
-        /* center or center and size of section to extract */
+        /* Center or center and size of section to extract */
         else if (isnum (*av)) {
 	    if (ac > 2 && isnum (*(av+1)) && (syscoor = wcscsys (*(av+2))) > 0) {
 		ra0 = str2ra (*av++);
@@ -253,7 +252,7 @@ char **av;
 		}
 	    }
 
-        /* range of pixels to extract */
+        /* Range of pixels to extract */
         else if (isrange (*av)) {
 	    if (crange == NULL)
 		crange = str;
@@ -261,12 +260,13 @@ char **av;
 		rrange = str;
 	    }
 
+	/* File with list of image files */
  	else if (*av[0] == '@') {
 	    listfile = *av + 1;
 	    }
 
         /* Image file */
-        else if (isfits (*av)) {
+        else if (isfits (*av) || isiraf (*av)) {
             if (nfile >= maxnfile) {
                 maxnfile = maxnfile * 2;
                 nbytes = maxnfile * sizeof (char *);
@@ -289,17 +289,17 @@ char **av;
     if (xdpix && !ydpix)
 	ydpix = xdpix;
 
-    /* now there are ac remaining file names starting at av[0] */
+    /* Process files from listfile one at a time */
     if (listfile && isimlist (listfile)) {
 	nfile = getfilelines (listfile);
 	if ((flist = fopen (listfile, "r")) == NULL) {
-	    fprintf (stderr,"I2F: Image list file %s cannot be read\n",
+	    fprintf (stderr,"GETFITS: Image list file %s cannot be read\n",
 		     listfile);
 	    usage ();
 	    }
 	for (ifile = 0; ifile < nfile; ifile++) {
 	    first_token (flist, 254, filename);
-	    ExtractFITS (filename,kwd,nkwd);
+	    (void) ExtractFITS (filename,kwd,nkwd);
 	    }
 	fclose (flist);
 	}
@@ -325,12 +325,15 @@ char *errmsg;	/* Error message */
     if (*errmsg)
 	fprintf (stderr, "*** %s ***\n", errmsg);
     fprintf (stderr,"Extract FITS files from FITS image files\n");
-    fprintf(stderr,"Usage: getfits -sv [-i num] [-o name] [-d dir] file.fits [xrange yrange] [x y dx [dy]] ...\n");
-    fprintf(stderr,"  or : getfits [-sv1][-i num][-o name] [-d path] @fitslist [xrange yrange] [x y dx [dy]]\n");
+    fprintf(stderr,"Usage: getfits -sv [-i num] [-o name] [-d dir] file.fits xrange yrange...\n");
+    fprintf(stderr,"  or : getfits -sv [-i num] [-o name] [-d dir] file.fits [x y dx [dy] ...\n");
+    fprintf(stderr,"  or : getfits [-sv1][-i num][-o name] [-d path] @fitslist xrange yrange\n");
+    fprintf(stderr,"  or : getfits [-sv1][-i num][-o name] [-d path] @fitslist x y dx [dy]\n");
     fprintf(stderr,"  xrange: Columns to extract in format x1-x2\n");
     fprintf(stderr,"  yrange: Rows to extract in format y1-y2\n");
-    fprintf(stderr,"  x y: Center pixel (column row) of region to extract\n");
-    fprintf(stderr,"  hh:mm:ss dd:mm:ss sys: Center pixel in sky coordintes\n");
+    fprintf(stderr,"  x y: Center pixel of region to extract\n");
+    fprintf(stderr,"       column row or\n");
+    fprintf(stderr,"       hh:mm:ss dd:mm:ss system (sky coordinates)\n");
     fprintf(stderr,"  dx dy: Width and height in pixels of region to extract\n");
     fprintf(stderr,"         (Height is same as width if omitted)\n");
     fprintf(stderr,"  -d dir: write FITS file(s) to this directory\n");
@@ -421,7 +424,7 @@ int	nkwd;
 	}
 
     if (ra0 > -99.0 && dec0 > -99.0) {
-	wcs = GetWCSFITS (name, header, verbose);
+	wcs = GetWCSFITS (name, verbose);
 	if (wcs->lngcor != NULL) {
 	    istnx = 1;
 	    }
@@ -467,6 +470,15 @@ int	nkwd;
 	ifrow1 = 1;
 	ifrow2 = nrows;
 	}
+
+    /* Return with error if both first and last row off image */
+    if ((ifrow1 < 1 && ifrow2 < 1) ||
+	(ifrow1 > nrows && ifrow2 > nrows)) {
+	fprintf (stderr,"GETFITS: Rows %d-%d off image %s\n",
+		 ifrow1, ifrow2, name);
+	return (1);
+	}
+
     if (ifrow1 < 1)
 	ifrow1 = 1;
     if (ifrow2 < 1)
@@ -492,6 +504,15 @@ int	nkwd;
 	ifcol1 = 1;
 	ifcol2 = ncols;
 	}
+
+    /* Return with error if both first and last column off image */
+    if ((ifcol1 < 1 && ifcol2 < 1) ||
+	(ifcol1 > ncols && ifcol2 > ncols)) {
+	fprintf (stderr,"GETFITS: Columns %d-%d off image %s\n",
+		 ifcol1, ifcol2, name);
+	return (1);
+	}
+
     if (ifcol1 < 1)
 	ifcol1 = 1;
     if (ifcol2 < 1)
@@ -726,4 +747,7 @@ char *newname;
  * Apr  4 2008	Make extracted TNX WCS dependent on original PLATE WCS
  *
  * Apr 10 2010	Fix bug so WCS is not accessed after it is freed
+ *
+ * Jan 22 2012	Print error, not blank file, if requested region is off image
+ * Sep 17 2013	Include fitswcs.h
  */
