@@ -40,7 +40,7 @@ static void usage();
 static void PrintValues();
 static int maxncond = 100;
 
-static char *RevMsg = "GETTAB WCSTools 3.8.7, 31 October 2012, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "GETTAB WCSTools 3.9.0, 29 August 2014, Jessica Mink (jmink@cfa.harvard.edu)";
 
 static int verbose = 0;		/* verbose/debugging flag */
 static int nfile = 0;
