@@ -27,7 +27,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-static char *RevMsg = "ISRANGE WCSTools 3.8.7, 31 October 2012, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "ISRANGE WCSTools 3.9.0, 29 August 2014, Jessica Mink (jmink@cfa.harvard.edu)";
 
 static int isrange();
 
