@@ -1,9 +1,9 @@
 /* File remap.c
- * October 15, 2010
+ * February 19, 2014
  * By Jessica Mink, Harvard-Smithsonian Center for Astrophysics
  * Send bug reports to jmink@cfa.harvard.edu
 
-   Copyright (C) 1999-2010
+   Copyright (C) 1999-2014
    Smithsonian Astrophysical Observatory, Cambridge, MA USA
 
    This program is free software; you can redistribute it and/or
@@ -28,8 +28,7 @@
 #include <errno.h>
 #include <unistd.h>
 #include <math.h>
-#include "libwcs/fitsfile.h"
-#include "libwcs/wcs.h"
+#include "libwcs/fitswcs.h"
 
 #define REMAP_CLOSEST	1
 #define REMAP_FLUX	2
@@ -50,7 +49,7 @@ static char *outname0 = "remap.fits";
 static char *outname;
 static char *wcsproj;           /* WCS projection name */
 
-static char *RevMsg = "REMAP WCSTools 3.8.7, 19 October 2012, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "REMAP WCSTools 3.9.0, 29 August 2014, Jessica Mink (jmink@cfa.harvard.edu)";
 static int nfiles = 0;
 static int fitsout = 1;
 static double secpix = 0;
@@ -58,7 +57,6 @@ static double secpix2 = 0;
 static int bitpix0 = 0; /* Output BITPIX, =input if 0 */
 static int RemapImage();
 static void getsection();
-extern struct WorldCoor *GetFITSWCS();
 static struct WorldCoor *wcsout = NULL;
 static char *irafheader;	/* IRAF image header */
 static char *headout;		/* FITS output header */
@@ -374,8 +372,8 @@ char	*message;	/* Error message */
     if (message != NULL)
 	fprintf (stderr, "ERROR: %c %s\n", arg, message);
     fprintf (stderr,"Remap FITS or IRAF images into single FITS image using WCS\n");
-    fprintf(stderr,"Usage: remap [-vf][-a rot][[-b][-j] ra dec][-i bits][-l num] file1.fit file2.fit ... filen.fit\n");
-    fprintf(stderr,"  or : remap [-vf][-a rot][[-b][-j] ra dec][-i bits][-l num] @filelist\n");
+    fprintf(stderr,"Usage: remap [-v][-f WCSfile][-a rot][[-b][-j] ra dec][-i bits][-l num] file1.fit file2.fit ... filen.fit\n");
+    fprintf(stderr,"  or : remap [-v][-f WCSfile][-a rot][[-b][-j] ra dec][-i bits][-l num] @filelist\n");
     fprintf(stderr,"  -a: Output rotation angle in degrees (default 0)\n");
     fprintf(stderr,"  -b ra dec: Output center in B1950 (FK4) RA and Dec\n");
     fprintf(stderr,"  -e long lat: Output center in ecliptic longitude and latitude\n");
@@ -945,4 +943,8 @@ double	*y2;		/* Upper right y coordinate (returned) */
  * Jan 10 2007	Drop unused variable dy
  *
  * Oct 15 2010	Use center coordinates of original image if not set
+ *
+ * Sep 17 2013  Include fitswcs.h
+ *
+ * Feb 19 2014	Update usage to -f WCSfile suggested by Steve Willner
  */
