@@ -1,9 +1,9 @@
 /* File sethead.c
- * September 1, 2011
+ * May 6, 2014
  * By Jessica Mink Harvard-Smithsonian Center for Astrophysics)
  * Send bug reports to jmink@cfa.harvard.edu
 
-   Copyright (C) 1996-2011
+   Copyright (C) 1996-2014
    Smithsonian Astrophysical Observatory, Cambridge, MA USA
 
    This program is free software; you can redistribute it and/or
@@ -66,7 +66,7 @@ static int addwcs = 0;
 static int errflag = 0;		/* Error return from program */
 static char *rootdir=NULL;	/* Root directory for input files */
 
-static char *RevMsg = "SETHEAD WCSTools 3.8.7, 31 October 2012, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "SETHEAD WCSTools 3.9.0, 29 August 2014, Jessica Mink (jmink@cfa.harvard.edu)";
 
 int
 main (ac, av)
@@ -223,7 +223,7 @@ char **av;
 		case 'x': /* FITS extension to read */
 		    if (ac < 2)
 			usage();
-		    if (isnum (*(av+1)))
+		    if (isnum (*(av+1)) || isrange (*(av+1)))
 			extensions = *++av;
 		    else {
 			extensions = calloc (16, 1);
@@ -517,8 +517,8 @@ char **av;
 		    namext = (char *) calloc (1, nch);
 		    strcpy (namext, fn[ifile]);
 		    strcat (namext, ",");
-		    strcat (namext, extension);
 		    sprintf (extension, "%d", j);
+		    strcat (namext, extension);
 		    if (SetValues (namext, nkwd, kwd, comment))
 			break;
 		    free (namext);
@@ -1471,4 +1471,6 @@ char	*comment[];	/* Comments for those keywords (none if NULL) */
  *
  * Jan  3 2011	Exit with errflag value to indicate an error
  * Sep  1 2011	Fix overflow bug by increasing size of history from 72 to 128
+ *
+ * May  6 2014	Fix bug so headers for multiple extensions can be changed
  */
