@@ -1,5 +1,5 @@
 /*** simpos.c - search object by its name from command line arguments
- *** March 3, 2009
+ *** February 1, 2013
  *** By Jessica Mink, sort of after IPAC byname.c for searching NED
  */
 
@@ -11,8 +11,10 @@
 #include "libwcs/wcscat.h"
 
 extern int   ned_errno;
+static char *searchorder = NULL;
+static int printall = 0;
 static void PrintUsage();
-static char *RevMsg = "SIMPOS 3.8.7, 19 October 2012, Jessica Mink SAO";
+static char *RevMsg = "SIMPOS 3.9.0, 29 August 2014, Jessica Mink SAO";
 
 int
 main (ac, av)
@@ -24,6 +26,7 @@ char *av[];
     int i;
     int verbose = 0;
     int printid = 0;
+    int printname = 0;
     int printdeg = 0;
     int nid = 0;
     int nobj = 0;
@@ -32,16 +35,20 @@ char *av[];
     int sysj = WCS_J2000;
     int tabout = 0;
     double ra, dec;
-    char *str, *objname, *posdec, *posra;
+    char *str, *objname, *posdec, *posra, *iend, *ieq;
     char *listfile;
     char rastr[32], decstr[32];
     char newobj[32];
-    char *buff, *idline, *posline, *errline, *id, *errend;
+    char *buff, *buffid, *idline, *posline, *errline, *id, *errend;
     char url[256];
     int lbuff;
     FILE *flist;
+    char cr, lf, eq;
 
     listfile = NULL;
+    cr = (char) 13;
+    lf = (char) 10;
+    eq = '=';
 
     str = *(av+1);
     if (!str || !strcmp (str, "help") || !strcmp (str, "-help"))
@@ -59,6 +66,10 @@ char *av[];
             while (c = *++str) {
             switch (c) {
 
+        	case 'a':       /* Print all ID information */
+	            printall = 1;
+		    break;
+
         	case 'b':       /* Print coordinates in B1950 */
 	            outsys = WCS_B1950;
 		    break;
@@ -79,6 +90,17 @@ char *av[];
 		    printid++;
 		    break;
 
+		case 'n':       /* Print object name */
+		    printname++;
+		    break;
+
+		case 's':       /* Database search order */
+		    if (ac < 2)
+			PrintUsage(NULL);
+		    searchorder = uppercase (*++av);
+		    ac--;
+		    break;
+
 		case 't':       /* Print output in tab-separated table */
 		    tabout++;
 		    break;
@@ -100,15 +122,15 @@ char *av[];
 	    if (isfile (listfile)) {
 		nfobj = getfilelines (listfile);
 		if (verbose)
-		    fprintf (stderr,"NEDPOS: %d objects from file %s\n",
+		    fprintf (stderr,"SIMPOS: %d objects from file %s\n",
 			     nfobj, listfile);
 		if ((flist = fopen (listfile, "r")) == NULL) {
-		    fprintf (stderr,"NEDPOS: List file %s cannot be read\n",
+		    fprintf (stderr,"SIMPOS: List file %s cannot be read\n",
 			     listfile);
 		    }
 		}
 	    else {
-		printf ("NEDPOS: List file %s does not exist\n", listfile);
+		printf ("SIMPOS: List file %s does not exist\n", listfile);
 		listfile = NULL;
 		}
 	    
@@ -146,7 +168,15 @@ char *av[];
 	if (verbose)
 	    printf ("%s -> ", objname);
 
-	strcpy (url, "http://vizier.u-strasbg.fr/cgi-bin/nph-sesame?");
+	/* strcpy (url, "http://vizier.u-strasbg.fr/cgi-bin/nph-sesame?"); */
+	strcpy (url, "http://cdsweb.u-strasbg.fr/cgi-bin/nph-sesame/-oI/~");
+	if (searchorder)
+	    strcat (url, searchorder);
+	else
+	    strcat (url, "NSV");
+	if (printid || printall)
+	    strcat (url, "A");
+	strcat (url, "?");
 	strcat (url, objname);
 	buff = webbuff (url, verbose, &lbuff);
 
@@ -157,6 +187,10 @@ char *av[];
 		fprintf (stderr,"*** No return from SIMBAD for %s\n",objname);
 	    continue;
 	    }
+	else if (printall) {
+	    (void) printf ("%s\n", buff);
+	    continue;
+	    }
 
 	/* Read number of objects identified */
 	if ((idline = strsrch (buff, "#=")) != NULL) {
@@ -166,7 +200,7 @@ char *av[];
 	    else
 		nid = 0;
 
-	/* Get position */
+	    /* Get position */
 	    if ((posline = strsrch (buff, "%J ")) != NULL) {
 		posra = posline + 3;
 		while (*posra == ' ')
@@ -229,12 +263,16 @@ char *av[];
 		    printf ("epoch	2000.0\n");
 		    }
 		printf ("program	%s\n",RevMsg);
-		printf ("id    	ra      	dec       ");
+		if (printname)
+		    printf ("id    	");
+		printf ("ra      	dec       ");
 		printf ("\n");
-		printf ("--	------------	------------");
+		if (printname)
+		    printf ("------	");
+		printf ("------------	------------");
 		printf ("\n");
 		}
-	    if (printid) {
+	    if (printname) {
 		printf ("%s", objname);
 		if (tabout)
 		    printf ("	");
@@ -293,6 +331,31 @@ char *av[];
 		    }
 		fprintf (stdout, "\n");
 		}
+	    if (printid) {
+		buffid = buff;
+		while ((buffid = strsrch (buffid, "%I ")) != NULL) {
+		    buffid = buffid + 3;
+		    if ((iend = strchr (buffid, lf))) {
+			*iend = (char) 0;
+			if ((ieq = strchr (buffid, eq)))
+			    *ieq = (char) 0;
+			printf ("%s\n", buffid);
+			if (ieq)
+			    *ieq = eq;
+			*iend = lf;
+			}
+		    else if ((iend = strchr (buffid,cr))) {
+			*iend = (char) 0;
+			if ((ieq = strchr (buffid, eq)))
+			    *ieq = (char) 0;
+			printf ("%s\n", buffid);
+			if (ieq)
+			    *ieq = eq;
+			*iend = cr;
+			}
+
+		    }
+		}
 	    }
 	free (buff);
 	}
@@ -311,11 +374,13 @@ char	*command;	/* Command where error occurred or NULL */
     fprintf (stderr,"        simpos [-idtv][b|e|g] @namelist ...\n");
     fprintf (stderr,"name(n): Objects for which to search (space -> _)\n");
     fprintf (stderr,"namelist: File with one object name per line\n");
+    fprintf (stderr,"-a: Print all information returned\n");
     fprintf (stderr,"-b: Print coordinates in B1950 instead of J2000\n");
     fprintf (stderr,"-d: Print coordinates in degrees instead of sexigesimal\n");
     fprintf (stderr,"-e: Print coordinates in ecliptic instead of J2000\n");
     fprintf (stderr,"-g: Print coordinates in galactic instead of J2000\n");
-    fprintf (stderr,"-i: Print ID returned from SIMBAD\n");
+    fprintf (stderr,"-i: Print ID(s) returned from SIMBAD\n");
+    fprintf (stderr,"-s [N][S][V]: Search order NED SIMBAD Vizier\n");
     fprintf (stderr,"-t: Print output as tab-separated table\n");
     fprintf (stderr,"-v: Print extra descriptive info\n");
     exit (1);
@@ -334,4 +399,9 @@ char	*command;	/* Command where error occurred or NULL */
  * Apr 16 2008	Fix @ mode for processing lists of objects
  * 
  * Mar  3 2009	Put -i option back in; print name only if requested
+ *
+ * Jan 28 2013	Update Vizier URL
+ * Feb  1 2013	Add -s NSV option to allow users to change search order
+ * Feb  1 2013	Add -a option to print everything which is returned
+ * Feb  1 2013	Fix -i option to print list of catalog IDs returned
  */
