@@ -12,7 +12,7 @@
 
 extern int   ned_errno;
 static void PrintUsage();
-static char *RevMsg = "SIMPOS 3.8.7, 19 October 2012, Jessica Mink SAO";
+static char *RevMsg = "SIMPOS 3.9.0, 29 August 2014, Jessica Mink SAO";
 
 int
 main (ac, av)
@@ -145,7 +145,8 @@ char *av[];
 	if (verbose)
 	    printf ("%s -> ", objname);
 
-	strcpy (url, "http://vizier.u-strasbg.fr/cgi-bin/nph-sesame?");
+	/* strcpy (url, "http://vizier.u-strasbg.fr/cgi-bin/nph-sesame?"); */
+	strcpy (url, "http://cdsweb.u-strasbg.fr/cgi-bin/nph-sesame/-ol?");
 	strcat (url, objname);
 	buff = webbuff (url, verbose, &lbuff);
 
