@@ -1,9 +1,9 @@
 /* File sumpix.c
- * May 16, 2012
+ * January 10, 2014
  * By Jessica Mink Harvard-Smithsonian Center for Astrophysics)
  * Send bug reports to jmink@cfa.harvard.edu
 
-   Copyright (C) 1999-2012
+   Copyright (C) 1999-2014
    Smithsonian Astrophysical Observatory, Cambridge, MA USA
 
    This program is free software; you can redistribute it and/or
@@ -32,11 +32,14 @@
 #include "libwcs/fitsfile.h"
 #include "libwcs/wcscat.h"
 
+#define MAXFILES 2000
+static int maxnfile = MAXFILES;
+
 static void usage();
 static void SumPix();
 extern double PhotPix();
 
-static char *RevMsg = "SUMPIX WCSTools 3.8.7, 19 October 2012, Jessica Mink SAO";
+static char *RevMsg = "SUMPIX WCSTools 3.9.0, 29 August 2014, Jessica Mink SAO";
 
 static int verbose = 0;		/* verbose/debugging flag */
 static int version = 0;	/* If 1, print only program name and version */
@@ -62,9 +65,17 @@ int ac;
 char **av;
 {
     char *str;
-    char *fn;
+    char *listfile = NULL;
+    char **fn;
+    char filename[256];
+    int ifile, nbytes;
+    FILE *flist;
+
     char *rrange;	/* Row range string */
     char *crange;	/* Column range string */
+    char *zrange;
+
+    int nfile = 0;
 
     /* Check for help or version command first */
     str = *(av+1);
@@ -77,7 +88,9 @@ char **av;
 
     crange = NULL;
     rrange = NULL;
-    fn = NULL;
+    zrange = (char *)calloc (4, sizeof(char));
+    strcpy (zrange, "0");
+    fn = (char **)calloc (maxnfile, sizeof(char *));
 
     /* crack arguments */
     for (av++; --ac > 0; av++) {
@@ -161,37 +174,56 @@ char **av;
         else if (isnum (*av) || isrange (*av)) {
 	    if (crange == NULL)
 		crange = *av;
-	    else {
+	    else
 		rrange = *av;
-		if (fn != NULL) {
-		    SumPix (fn, crange, rrange);
-		    }
-		}
 	    }
 
-	/* read filename */
-	else {
-	    fn = *av;
+	/* File with list of image files */
+	else if (*av[0] == '@') {
+	    listfile = *av + 1;
+	    }
 
-	    if (!compmean && !compvar && !compstd)
-		compsum++;
-	    if (crange && rrange)
-		SumPix (fn, crange, rrange);
-	    else if (crange)
-		SumPix (fn, crange, "0");
-	    else if (rrange)
-		SumPix (fn, "0", rrange);
-	    else {
-		if (ac > 0) {
-		    if (!isnum (*(av+1)) && !isrange (*(av+1)))
-			SumPix (fn, "0", "0");
-		    }
-		else
-		    SumPix (fn, "0", "0");
+        /* Image file */
+        else if (isfits (*av) || isiraf (*av)) {
+	    if (nfile >= maxnfile) {
+		maxnfile = maxnfile * 2;
+		nbytes = maxnfile * sizeof (char *);
+		fn = (char **) realloc ((void *)fn, nbytes);
 		}
+	    fn[nfile] = *av;
+	    nfile++;
 	    }
         }
 
+    if (crange == NULL)
+	crange = zrange;
+    if (rrange == NULL)
+	rrange = zrange;
+    if (!compmean && !compvar && !compstd)
+	compsum++;
+
+    /* Process files from listfile one at a time */
+    if (listfile && isimlist (listfile)) {
+	nfile = getfilelines (listfile);
+	if ((flist = fopen (listfile, "r")) == NULL) {
+	    fprintf (stderr,"SUMPIX: Image list file %s cannot be read\n",
+		     listfile);
+	    usage ();
+	    }
+	for (ifile = 0; ifile < nfile; ifile++) {
+	    first_token (flist, 254, filename);
+	    SumPix (filename, crange, rrange);
+	    }
+	fclose (flist);
+	}
+
+    /* Process files already read from the command line */
+    else if (fn) {
+	for (ifile = 0; ifile < nfile; ifile++) {
+	    SumPix (fn[ifile], crange, rrange);
+	    }
+	}
+
     return (0);
 }
 
@@ -803,4 +835,6 @@ char *rrange;	/* Row range string */
  * May 16 2012	Add options i to print index and e to compute medians
  * May 16 2012	Add option t to separate values by tabs
  * May 16 2012	Add option h to print headings
+ *
+ * Jan 10 2014	Add list file with @ as command line option
  */
