@@ -49,7 +49,7 @@ static int printhead = 0;
 static char printonly = 'n';
 static int version = 0;		/* If 1, print only program name and version */
 
-static char *RevMsg = "XY2SKY WCSTools 3.8.7, 31 October 2012, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "XY2SKY WCSTools 3.9.0, 29 August 2014, Jessica Mink (jmink@cfa.harvard.edu)";
 
 int
 main (ac, av)
@@ -419,6 +419,7 @@ char **av;
 	    ln = listname;
 	    while (*ln++)
 		*(ln-1) = *ln;
+	    *ln = (char) 0;
 	    if (strcmp (listname,"STDIN")==0 || strcmp (listname,"stdin")==0) {
 		fd = stdin;
 		nlines = 10000;
